Container Management System
Docker/Podman integration: build images, run containers, exec commands, manage volumes, compose support.
Features
- Container runtime abstraction (Docker/Podman)
- Image management (build, pull, push, list)
- Container lifecycle (run, stop, start, remove)
- Volume and network management
- Docker Compose support
Structs
- Build
Context - Build context for image builds
- Command
Result - Command result
- Compose
File - Docker Compose file
- Compose
Manager - Compose manager
- Compose
Network - Compose network definition
- Compose
Service - Docker Compose service
- Compose
Volume - Compose volume definition
- Container
- Container information
- Container
Manager - Container manager
- Exec
Config - Exec configuration
- Image
- Image information
- Network
- Network information
- Port
Mapping - Port mapping
- Volume
- Volume information
- Volume
Mount - Volume mount
Enums
- Container
Status - Container status
- Mount
Type - Mount type
- Protocol
- Network protocol
- Runtime
Type - Container runtime type
Functions
- validate_
image_ name - Validate a container image name to prevent shell injection.