Module doctor

Module doctor 

Selfware Doctor — system diagnostics and dependency checker.

Checks that all required and optional tools are available on the system. Run via selfware doctor or automatically on first launch.

Structs

DoctorCheck
A single diagnostic check result.
DoctorReport
Full diagnostic report.

Enums

Category
Category of a doctor check.
CheckStatus
Result status of a single check.
OverallHealth
Overall health of the system.

Functions

run_doctor
Run all diagnostic checks and return a report.