macro_rules! tool_span {
($tool_name:expr) => { ... };
}Expand description
Create a span for tracking tool execution with automatic duration and outcome logging
macro_rules! tool_span {
($tool_name:expr) => { ... };
}Create a span for tracking tool execution with automatic duration and outcome logging