pub struct SwlRuntime { /* private fields */ }Expand description
SWL Workflow Runtime
Implementations
Sourceimpl SwlRuntime
impl SwlRuntime
Sourcepub fn with_tool_registry(
client: Arc<ApiClient>,
tool_registry: Arc<ToolRegistry>,
) -> Self
pub fn with_tool_registry( client: Arc<ApiClient>, tool_registry: Arc<ToolRegistry>, ) -> Self
Create a new runtime with a custom tool registry
Sourcepub fn new_dry_run() -> Self
pub fn new_dry_run() -> Self
Create a dry-run runtime (no actual LLM calls)
Sourcepub async fn with_file_persistence(
client: Arc<ApiClient>,
workflow_name: &str,
) -> Result<Self>
pub async fn with_file_persistence( client: Arc<ApiClient>, workflow_name: &str, ) -> Result<Self>
Create a runtime with file-based state persistence
Sourcepub fn with_max_tool_iterations(self, max: usize) -> Self
pub fn with_max_tool_iterations(self, max: usize) -> Self
Set the maximum number of tool iterations per agent execution
Sourcepub async fn execute_workflow(
&self,
doc: &SwlDocument,
workflow_name: &str,
inputs: HashMap<String, VarValue>,
) -> Result<ExecutionResult>
pub async fn execute_workflow( &self, doc: &SwlDocument, workflow_name: &str, inputs: HashMap<String, VarValue>, ) -> Result<ExecutionResult>
Execute a workflow from a document with state persistence
Sourcepub async fn persist_state(&self) -> Result<()>
pub async fn persist_state(&self) -> Result<()>
Persist the current execution context state
Sourcepub async fn load_state(&self) -> Result<()>
pub async fn load_state(&self) -> Result<()>
Load state from persistence
Sourcepub async fn get_context(&self) -> ExecutionContext
pub async fn get_context(&self) -> ExecutionContext
Get execution context
Sourcepub async fn get_execution_trace(&self) -> Vec<ExecutionEvent>
pub async fn get_execution_trace(&self) -> Vec<ExecutionEvent>
Get the execution trace (telemetry events)
Sourcepub async fn get_telemetry_summary(&self) -> WorkflowTelemetry
pub async fn get_telemetry_summary(&self) -> WorkflowTelemetry
Get aggregated telemetry summary
Sourcepub async fn export_telemetry_json(&self) -> Result<String>
pub async fn export_telemetry_json(&self) -> Result<String>
Export telemetry data as JSON string
Sourcepub async fn clear_telemetry(&self)
pub async fn clear_telemetry(&self)
Clear all telemetry data
Sourcepub async fn get_agent_trace(&self, agent_name: &str) -> Vec<ExecutionEvent>
pub async fn get_agent_trace(&self, agent_name: &str) -> Vec<ExecutionEvent>
Get the raw execution trace for a specific agent