pub struct LspClientHandle { /* private fields */ }Expand description
Shared, lazily-initialized LSP client.
All four LSP tools hold an Arc to the same LspClientHandle, which
ensures only one set of language servers is started per session.
Implementations