Selfware Doctor — system diagnostics and dependency checker.
Checks that all required and optional tools are available on the system.
Run via selfware doctor or automatically on first launch.
Structs
- Doctor
Check - A single diagnostic check result.
- Doctor
Report - Full diagnostic report.
Enums
- Category
- Category of a doctor check.
- Check
Status - Result status of a single check.
- Overall
Health - Overall health of the system.
Functions
- run_
doctor - Run all diagnostic checks and return a report.