MCP server implementation.
Exposes Selfware’s tools and project resources to external AI clients via the Model Context Protocol (JSON-RPC 2.0 over stdio).
The server reads Content-Length framed JSON-RPC requests from stdin and writes Content-Length framed JSON-RPC responses to stdout. This is the same framing used by LSP (Language Server Protocol).
Structs
- Json
RpcError - JSON-RPC 2.0 error object.
- Json
RpcRequest - Incoming JSON-RPC 2.0 request (or notification when
idisNone). - Json
RpcResponse - Outgoing JSON-RPC 2.0 response.
- McpServer
- MCP server that exposes Selfware tools and project resources.
Functions
- run_
mcp_ server - Run the MCP server, reading from stdin and writing to stdout.